"""integration tests for waylay.auth module"""
import pytest

from waylay.auth import (
    TokenCredentials,
    WaylayTokenAuth
)

def test_client_authentication(waylay_test_client_credentials):
    "WaylayTokenAuth resolves a token from client credentials"
    auth = WaylayTokenAuth(waylay_test_client_credentials)
    assert auth.current_token is None
    token = auth.assure_valid_token()
    assert auth.current_token is token
    assert_valid_token(token, waylay_test_client_credentials.accounts_url)


def test_token_authentication(waylay_test_accounts_url, waylay_test_token_string):
    token_cred = TokenCredentials(waylay_test_token_string, accounts_url=waylay_test_accounts_url)
    auth = WaylayTokenAuth(token_cred)
    assert auth.current_token is not None
    current_token = auth.current_token
    assert current_token == auth.assure_valid_token()
    assert auth.current_token is current_token
    assert_valid_token(current_token, waylay_test_accounts_url)


def assert_valid_token(token, accounts_url):
    assert token.domain is not None
    assert token.subject is not None
    assert token.expires_at is not None
    assert token.is_valid
    assert 'tsanalytics' in token.licenses
    assert token.permissions
    assert token.tenant is not None
    assert token is token.validate(accounts_url)
    assert token.groups is not None
